@@ -136,9 +136,10 @@ releases:
 			}
 
 			var listErr error
-			out := testutil.CaptureStdout(func() {
+			out, err := testutil.CaptureStdout(func() {
 				listErr = app.ListReleases(cfg)
 			})
+			assert.NoError(t, err)
 
 			var gotErr string
 			if listErr != nil {
@@ -277,10 +278,11 @@ releases:
 
 	expectNoCallsToHelm(app)
 
-	out := testutil.CaptureStdout(func() {
+	out, err := testutil.CaptureStdout(func() {
 		err := app.ListReleases(cfg)
 		assert.Nil(t, err)
 	})
+	assert.NoError(t, err)
 
 	expected := `[{"name":"myrelease1","namespace":"testNamespace","enabled":true,"installed":false,"labels":"id:myrelease1","chart":"mychart1","version":""},{"name":"myrelease2","namespace":"testNamespace","enabled":false,"installed":true,"labels":"","chart":"mychart1","version":""},{"name":"myrelease3","namespace":"testNamespace","enabled":true,"installed":true,"labels":"","chart":"mychart1","version":""},{"name":"myrelease4","namespace":"testNamespace","enabled":true,"installed":true,"labels":"id:myrelease1","chart":"mychart1","version":""}]
 `
