@@ -34,6 +34,7 @@ func listFlags(namespace, kubeContext string) string {
 
 type destroyConfig struct {
 	args                   string
+	cascade                string
 	concurrency            int
 	interactive            bool
 	skipDeps               bool
@@ -46,6 +47,10 @@ func (d destroyConfig) Args() string {
 	return d.args
 }
 
+func (d destroyConfig) Cascade() string {
+	return d.cascade
+}
+
 func (d destroyConfig) SkipCharts() bool {
 	return d.skipCharts
 }
@@ -310,8 +315,8 @@ anotherbackend 	4       	Fri Nov  1 08:40:07 2019	DEPLOYED	anotherbackend-3.1.0
 			},
 			log: `processing file "helmfile.yaml" in directory "."
 changing working directory to "/path/to"
-first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default map[] map[]}, overrode=<nil>
-first-pass uses: &{default map[] map[]}
+first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default  map[] map[]}, overrode=<nil>
+first-pass uses: &{default  map[] map[]}
 first-pass rendering output of "helmfile.yaml.part.0":
  0: 
  1: releases:
@@ -369,8 +374,8 @@ first-pass rendering output of "helmfile.yaml.part.0":
 53:   chart: stable/envoy
 54: 
 
-first-pass produced: &{default map[] map[]}
-first-pass rendering result of "helmfile.yaml.part.0": {default map[] map[]}
+first-pass produced: &{default  map[] map[]}
+first-pass rendering result of "helmfile.yaml.part.0": {default  map[] map[]}
 vals:
 map[]
 defaultVals:[]
@@ -431,7 +436,7 @@ second-pass rendering result of "helmfile.yaml.part.0":
 53:   chart: stable/envoy
 54: 
 
-merged environment: &{default map[] map[]}
+merged environment: &{default  map[] map[]}
 10 release(s) found in helmfile.yaml
 
 processing 5 groups of releases in this order:
@@ -519,8 +524,8 @@ anotherbackend 	4       	Fri Nov  1 08:40:07 2019	DEPLOYED	anotherbackend-3.1.0
 			},
 			log: `processing file "helmfile.yaml" in directory "."
 changing working directory to "/path/to"
-first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default map[] map[]}, overrode=<nil>
-first-pass uses: &{default map[] map[]}
+first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default  map[] map[]}, overrode=<nil>
+first-pass uses: &{default  map[] map[]}
 first-pass rendering output of "helmfile.yaml.part.0":
  0: 
  1: releases:
@@ -578,8 +583,8 @@ first-pass rendering output of "helmfile.yaml.part.0":
 53:   chart: stable/envoy
 54: 
 
-first-pass produced: &{default map[] map[]}
-first-pass rendering result of "helmfile.yaml.part.0": {default map[] map[]}
+first-pass produced: &{default  map[] map[]}
+first-pass rendering result of "helmfile.yaml.part.0": {default  map[] map[]}
 vals:
 map[]
 defaultVals:[]
@@ -640,7 +645,7 @@ second-pass rendering result of "helmfile.yaml.part.0":
 53:   chart: stable/envoy
 54: 
 
-merged environment: &{default map[] map[]}
+merged environment: &{default  map[] map[]}
 1 release(s) matching name=logging found in helmfile.yaml
 
 processing 1 groups of releases in this order:
@@ -677,8 +682,8 @@ changing working directory back to "/path/to"
 			},
 			log: `processing file "helmfile.yaml" in directory "."
 changing working directory to "/path/to"
-first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default map[] map[]}, overrode=<nil>
-first-pass uses: &{default map[] map[]}
+first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default  map[] map[]}, overrode=<nil>
+first-pass uses: &{default  map[] map[]}
 first-pass rendering output of "helmfile.yaml.part.0":
  0: 
  1: releases:
@@ -691,8 +696,8 @@ first-pass rendering output of "helmfile.yaml.part.0":
  8:   - backend-v1
  9: 
 
-first-pass produced: &{default map[] map[]}
-first-pass rendering result of "helmfile.yaml.part.0": {default map[] map[]}
+first-pass produced: &{default  map[] map[]}
+first-pass rendering result of "helmfile.yaml.part.0": {default  map[] map[]}
 vals:
 map[]
 defaultVals:[]
@@ -708,7 +713,7 @@ second-pass rendering result of "helmfile.yaml.part.0":
  8:   - backend-v1
  9: 
 
-merged environment: &{default map[] map[]}
+merged environment: &{default  map[] map[]}
 2 release(s) found in helmfile.yaml
 
 processing 2 groups of releases in this order:
@@ -749,8 +754,8 @@ changing working directory back to "/path/to"
 			},
 			log: `processing file "helmfile.yaml" in directory "."
 changing working directory to "/path/to"
-first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default map[] map[]}, overrode=<nil>
-first-pass uses: &{default map[] map[]}
+first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default  map[] map[]}, overrode=<nil>
+first-pass uses: &{default  map[] map[]}
 first-pass rendering output of "helmfile.yaml.part.0":
  0: 
  1: releases:
@@ -763,8 +768,8 @@ first-pass rendering output of "helmfile.yaml.part.0":
  8:   - backend-v1
  9: 
 
-first-pass produced: &{default map[] map[]}
-first-pass rendering result of "helmfile.yaml.part.0": {default map[] map[]}
+first-pass produced: &{default  map[] map[]}
+first-pass rendering result of "helmfile.yaml.part.0": {default  map[] map[]}
 vals:
 map[]
 defaultVals:[]
@@ -780,7 +785,7 @@ second-pass rendering result of "helmfile.yaml.part.0":
  8:   - backend-v1
  9: 
 
-merged environment: &{default map[] map[]}
+merged environment: &{default  map[] map[]}
 2 release(s) found in helmfile.yaml
 
 processing 2 groups of releases in this order:
