@@ -36,6 +36,7 @@ type diffConfig struct {
 	diffOutput             string
 	concurrency            int
 	detailedExitcode       bool
+	stripTrailingCR        bool
 	interactive            bool
 	skipDiffOnInstall      bool
 	reuseValues            bool
@@ -126,6 +127,10 @@ func (a diffConfig) DetailedExitcode() bool {
 	return a.detailedExitcode
 }
 
+func (a diffConfig) StripTrailingCR() bool {
+	return a.stripTrailingCR
+}
+
 func (a diffConfig) Interactive() bool {
 	return a.interactive
 }
@@ -979,8 +984,8 @@ releases:
 			error:       `in ./helmfile.yaml: release "default/default/external-secrets" depends on "default/kube-system/kubernetes-external-secrets" which does not match the selectors. Please add a selector like "--selector name=kubernetes-external-secrets", or indicate whether to skip (--skip-needs) or include (--include-needs) these dependencies`,
 			log: `processing file "helmfile.yaml" in directory "."
 changing working directory to "/path/to"
-first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default map[] map[]}, overrode=<nil>
-first-pass uses: &{default map[] map[]}
+first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default  map[] map[]}, overrode=<nil>
+first-pass uses: &{default  map[] map[]}
 first-pass rendering output of "helmfile.yaml.part.0":
  0: 
  1: 
@@ -1007,8 +1012,8 @@ first-pass rendering output of "helmfile.yaml.part.0":
 22:   - default/external-secrets
 23: 
 
-first-pass produced: &{default map[] map[]}
-first-pass rendering result of "helmfile.yaml.part.0": {default map[] map[]}
+first-pass produced: &{default  map[] map[]}
+first-pass rendering result of "helmfile.yaml.part.0": {default  map[] map[]}
 vals:
 map[]
 defaultVals:[]
@@ -1038,7 +1043,7 @@ second-pass rendering result of "helmfile.yaml.part.0":
 22:   - default/external-secrets
 23: 
 
-merged environment: &{default map[] map[]}
+merged environment: &{default  map[] map[]}
 2 release(s) matching app=test found in helmfile.yaml
 
 err: release "default/default/external-secrets" depends on "default/kube-system/kubernetes-external-secrets" which does not match the selectors. Please add a selector like "--selector name=kubernetes-external-secrets", or indicate whether to skip (--skip-needs) or include (--include-needs) these dependencies
@@ -1084,8 +1089,8 @@ releases:
 			concurrency: 1,
 			log: `processing file "helmfile.yaml" in directory "."
 changing working directory to "/path/to"
-first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default map[] map[]}, overrode=<nil>
-first-pass uses: &{default map[] map[]}
+first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default  map[] map[]}, overrode=<nil>
+first-pass uses: &{default  map[] map[]}
 first-pass rendering output of "helmfile.yaml.part.0":
  0: 
  1: 
@@ -1112,8 +1117,8 @@ first-pass rendering output of "helmfile.yaml.part.0":
 22:   - default/external-secrets
 23: 
 
-first-pass produced: &{default map[] map[]}
-first-pass rendering result of "helmfile.yaml.part.0": {default map[] map[]}
+first-pass produced: &{default  map[] map[]}
+first-pass rendering result of "helmfile.yaml.part.0": {default  map[] map[]}
 vals:
 map[]
 defaultVals:[]
@@ -1143,7 +1148,7 @@ second-pass rendering result of "helmfile.yaml.part.0":
 22:   - default/external-secrets
 23: 
 
-merged environment: &{default map[] map[]}
+merged environment: &{default  map[] map[]}
 0 release(s) matching app=test_non_existent found in helmfile.yaml
 
 changing working directory back to "/path/to"
@@ -1180,8 +1185,8 @@ releases:
 			error:       `in ./helmfile.yaml: release "default//foo" depends on "default//bar" which does not match the selectors. Please add a selector like "--selector name=bar", or indicate whether to skip (--skip-needs) or include (--include-needs) these dependencies`,
 			log: `processing file "helmfile.yaml" in directory "."
 changing working directory to "/path/to"
-first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default map[] map[]}, overrode=<nil>
-first-pass uses: &{default map[] map[]}
+first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default  map[] map[]}, overrode=<nil>
+first-pass uses: &{default  map[] map[]}
 first-pass rendering output of "helmfile.yaml.part.0":
  0: 
  1: releases:
@@ -1193,8 +1198,8 @@ first-pass rendering output of "helmfile.yaml.part.0":
  7:   - bar
  8: 
 
-first-pass produced: &{default map[] map[]}
-first-pass rendering result of "helmfile.yaml.part.0": {default map[] map[]}
+first-pass produced: &{default  map[] map[]}
+first-pass rendering result of "helmfile.yaml.part.0": {default  map[] map[]}
 vals:
 map[]
 defaultVals:[]
@@ -1209,7 +1214,7 @@ second-pass rendering result of "helmfile.yaml.part.0":
  7:   - bar
  8: 
 
-merged environment: &{default map[] map[]}
+merged environment: &{default  map[] map[]}
 1 release(s) matching name=foo found in helmfile.yaml
 
 err: release "default//foo" depends on "default//bar" which does not match the selectors. Please add a selector like "--selector name=bar", or indicate whether to skip (--skip-needs) or include (--include-needs) these dependencies
@@ -1243,8 +1248,8 @@ releases:
 			error:       `in ./helmfile.yaml: release(s) "default//foo" depend(s) on an undefined release "default//bar". Perhaps you made a typo in "needs" or forgot defining a release named "bar" with appropriate "namespace" and "kubeContext"?`,
 			log: `processing file "helmfile.yaml" in directory "."
 changing working directory to "/path/to"
-first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default map[] map[]}, overrode=<nil>
-first-pass uses: &{default map[] map[]}
+first-pass rendering starting for "helmfile.yaml.part.0": inherited=&{default  map[] map[]}, overrode=<nil>
+first-pass uses: &{default  map[] map[]}
 first-pass rendering output of "helmfile.yaml.part.0":
  0: 
  1: releases:
@@ -1257,8 +1262,8 @@ first-pass rendering output of "helmfile.yaml.part.0":
  8:   - bar
  9: 
 
-first-pass produced: &{default map[] map[]}
-first-pass rendering result of "helmfile.yaml.part.0": {default map[] map[]}
+first-pass produced: &{default  map[] map[]}
+first-pass rendering result of "helmfile.yaml.part.0": {default  map[] map[]}
 vals:
 map[]
 defaultVals:[]
@@ -1274,7 +1279,7 @@ second-pass rendering result of "helmfile.yaml.part.0":
  8:   - bar
  9: 
 
-merged environment: &{default map[] map[]}
+merged environment: &{default  map[] map[]}
 2 release(s) found in helmfile.yaml
 
 err: release(s) "default//foo" depend(s) on an undefined release "default//bar". Perhaps you made a typo in "needs" or forgot defining a release named "bar" with appropriate "namespace" and "kubeContext"?
