@@ -13,9 +13,9 @@ var (
 )
 
 // checkerFunc is a function that checks the helmState.
-type checkerFunc func(string, map[string]interface{}) (bool, error)
+type checkerFunc func(string, map[string]any) (bool, error)
 
-func forbidEnvironmentsWithReleases(filePath string, releaseState map[string]interface{}) (bool, error) {
+func forbidEnvironmentsWithReleases(filePath string, releaseState map[string]any) (bool, error) {
 	// forbid environments and releases to be defined at the same yaml part
 	_, hasEnvironments := releaseState["environments"]
 	_, hasReleases := releaseState["releases"]
@@ -30,7 +30,7 @@ var checkerFuncs = []checkerFunc{
 }
 
 // Checker is a policy checker for the helmfile state.
-func Checker(filePath string, helmState map[string]interface{}) (bool, error) {
+func Checker(filePath string, helmState map[string]any) (bool, error) {
 	for _, fn := range checkerFuncs {
 		if isStrict, err := fn(filePath, helmState); err != nil {
 			return isStrict, err
