@@ -1073,7 +1073,6 @@ func Test_normalizeChart(t *testing.T) {
 }
 
 // mocking helmexec.Interface
-
 func TestHelmState_SyncRepos(t *testing.T) {
 	tests := []struct {
 		name  string
@@ -1086,18 +1085,16 @@ func TestHelmState_SyncRepos(t *testing.T) {
 			name: "normal repository",
 			repos: []RepositorySpec{
 				{
-					Name:            "name",
-					URL:             "http://example.com/",
-					CertFile:        "",
-					KeyFile:         "",
-					Username:        "",
-					Password:        "",
-					PassCredentials: "",
-					SkipTLSVerify:   "",
+					Name:     "name",
+					URL:      "http://example.com/",
+					CertFile: "",
+					KeyFile:  "",
+					Username: "",
+					Password: "",
 				},
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "http://example.com/", "", "", "", "", "", "", "", ""},
+			want: []string{"name", "http://example.com/", "", "", "", "", "", "", "false", "false"},
 		},
 		{
 			name: "ACR hosted repository",
@@ -1108,57 +1105,51 @@ func TestHelmState_SyncRepos(t *testing.T) {
 				},
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "", "", "", "", "", "", "acr", "", ""},
+			want: []string{"name", "", "", "", "", "", "", "acr", "false", "false"},
 		},
 		{
 			name: "repository with cert and key",
 			repos: []RepositorySpec{
 				{
-					Name:            "name",
-					URL:             "http://example.com/",
-					CertFile:        "certfile",
-					KeyFile:         "keyfile",
-					Username:        "",
-					Password:        "",
-					PassCredentials: "",
-					SkipTLSVerify:   "",
+					Name:     "name",
+					URL:      "http://example.com/",
+					CertFile: "certfile",
+					KeyFile:  "keyfile",
+					Username: "",
+					Password: "",
 				},
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "http://example.com/", "", "certfile", "keyfile", "", "", "", "", ""},
+			want: []string{"name", "http://example.com/", "", "certfile", "keyfile", "", "", "", "false", "false"},
 		},
 		{
 			name: "repository with ca file",
 			repos: []RepositorySpec{
 				{
-					Name:            "name",
-					URL:             "http://example.com/",
-					CaFile:          "cafile",
-					Username:        "",
-					Password:        "",
-					PassCredentials: "",
-					SkipTLSVerify:   "",
+					Name:     "name",
+					URL:      "http://example.com/",
+					CaFile:   "cafile",
+					Username: "",
+					Password: "",
 				},
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "http://example.com/", "cafile", "", "", "", "", "", "", ""},
+			want: []string{"name", "http://example.com/", "cafile", "", "", "", "", "", "false", "false"},
 		},
 		{
 			name: "repository with username and password",
 			repos: []RepositorySpec{
 				{
-					Name:            "name",
-					URL:             "http://example.com/",
-					CertFile:        "",
-					KeyFile:         "",
-					Username:        "example_user",
-					Password:        "example_password",
-					PassCredentials: "",
-					SkipTLSVerify:   "",
+					Name:     "name",
+					URL:      "http://example.com/",
+					CertFile: "",
+					KeyFile:  "",
+					Username: "example_user",
+					Password: "example_password",
 				},
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "http://example.com/", "", "", "", "example_user", "example_password", "", "", ""},
+			want: []string{"name", "http://example.com/", "", "", "", "example_user", "example_password", "", "false", "false"},
 		},
 		{
 			name: "repository with username and password and pass-credentials",
@@ -1170,25 +1161,22 @@ func TestHelmState_SyncRepos(t *testing.T) {
 					KeyFile:         "",
 					Username:        "example_user",
 					Password:        "example_password",
-					PassCredentials: "true",
-					SkipTLSVerify:   "",
+					PassCredentials: true,
 				},
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "http://example.com/", "", "", "", "example_user", "example_password", "", "true", ""},
+			want: []string{"name", "http://example.com/", "", "", "", "example_user", "example_password", "", "true", "false"},
 		},
 		{
 			name: "repository without username and password and environment with username and password",
 			repos: []RepositorySpec{
 				{
-					Name:            "name",
-					URL:             "http://example.com/",
-					CertFile:        "",
-					KeyFile:         "",
-					Username:        "",
-					Password:        "",
-					PassCredentials: "",
-					SkipTLSVerify:   "",
+					Name:     "name",
+					URL:      "http://example.com/",
+					CertFile: "",
+					KeyFile:  "",
+					Username: "",
+					Password: "",
 				},
 			},
 			envs: map[string]string{
@@ -1196,20 +1184,18 @@ func TestHelmState_SyncRepos(t *testing.T) {
 				"NAME_PASSWORD": "example_password",
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "http://example.com/", "", "", "", "example_user", "example_password", "", "", ""},
+			want: []string{"name", "http://example.com/", "", "", "", "example_user", "example_password", "", "false", "false"},
 		},
 		{
 			name: "repository with username and password and environment with username and password",
 			repos: []RepositorySpec{
 				{
-					Name:            "name",
-					URL:             "http://example.com/",
-					CertFile:        "",
-					KeyFile:         "",
-					Username:        "example_user1",
-					Password:        "example_password1",
-					PassCredentials: "",
-					SkipTLSVerify:   "",
+					Name:     "name",
+					URL:      "http://example.com/",
+					CertFile: "",
+					KeyFile:  "",
+					Username: "example_user1",
+					Password: "example_password1",
 				},
 			},
 			envs: map[string]string{
@@ -1217,24 +1203,23 @@ func TestHelmState_SyncRepos(t *testing.T) {
 				"NAME_PASSWORD": "example_password2",
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "http://example.com/", "", "", "", "example_user1", "example_password1", "", "", ""},
+			want: []string{"name", "http://example.com/", "", "", "", "example_user1", "example_password1", "", "false", "false"},
 		},
 		{
 			name: "repository with skip-tls-verify",
 			repos: []RepositorySpec{
 				{
-					Name:            "name",
-					URL:             "http://example.com/",
-					CertFile:        "",
-					KeyFile:         "",
-					Username:        "",
-					Password:        "",
-					PassCredentials: "",
-					SkipTLSVerify:   "true",
+					Name:          "name",
+					URL:           "http://example.com/",
+					CertFile:      "",
+					KeyFile:       "",
+					Username:      "",
+					Password:      "",
+					SkipTLSVerify: true,
 				},
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "http://example.com/", "", "", "", "", "", "", "", "true"},
+			want: []string{"name", "http://example.com/", "", "", "", "", "", "", "false", "true"},
 		},
 	}
 	for i := range tests {
@@ -1365,7 +1350,7 @@ func TestHelmState_SyncReleases(t *testing.T) {
 				},
 				logger:         logger,
 				valsRuntime:    valsRuntime,
-				RenderedValues: map[string]interface{}{},
+				RenderedValues: map[string]any{},
 			}
 			if errs := state.SyncReleases(&AffectedReleases{}, tt.helm, []string{}, 1); len(errs) > 0 {
 				if len(errs) != len(tt.wantErrorMsgs) {
@@ -1433,7 +1418,7 @@ func TestHelmState_SyncReleases_MissingValuesFileForUndesiredRelease(t *testing.
 			release: ReleaseSpec{
 				Name:   "foo",
 				Chart:  "../../foo-bar",
-				Values: []interface{}{"noexistent.values.yaml"},
+				Values: []any{"noexistent.values.yaml"},
 			},
 			listResult:    ``,
 			expectedError: `failed processing release foo: values file matching "noexistent.values.yaml" does not exist in "."`,
@@ -1443,7 +1428,7 @@ func TestHelmState_SyncReleases_MissingValuesFileForUndesiredRelease(t *testing.
 			release: ReleaseSpec{
 				Name:   "foo",
 				Chart:  "../../foo-bar",
-				Values: []interface{}{"noexistent.values.yaml"},
+				Values: []any{"noexistent.values.yaml"},
 			},
 			listResult: `NAME 	REVISION	UPDATED                 	STATUS  	CHART                      	APP VERSION	NAMESPACE
 										foo	1       	Wed Apr 17 17:39:04 2019	DEPLOYED	foo-bar-2.0.4	0.1.0      	default`,
@@ -1454,7 +1439,7 @@ func TestHelmState_SyncReleases_MissingValuesFileForUndesiredRelease(t *testing.
 			release: ReleaseSpec{
 				Name:      "foo",
 				Chart:     "../../foo-bar",
-				Values:    []interface{}{"noexistent.values.yaml"},
+				Values:    []any{"noexistent.values.yaml"},
 				Installed: &no,
 			},
 			listResult: `NAME 	REVISION	UPDATED                 	STATUS  	CHART                      	APP VERSION	NAMESPACE
@@ -1472,7 +1457,7 @@ func TestHelmState_SyncReleases_MissingValuesFileForUndesiredRelease(t *testing.
 				},
 				logger:         logger,
 				valsRuntime:    valsRuntime,
-				RenderedValues: map[string]interface{}{},
+				RenderedValues: map[string]any{},
 			}
 			fs := testhelper.NewTestFs(map[string]string{})
 			state = injectFs(state, fs)
@@ -1619,7 +1604,7 @@ func TestHelmState_SyncReleasesAffectedRealeases(t *testing.T) {
 				},
 				logger:         logger,
 				valsRuntime:    valsRuntime,
-				RenderedValues: map[string]interface{}{},
+				RenderedValues: map[string]any{},
 			}
 			helm := &exectest.Helm{
 				Lists: map[exectest.ListKey]string{},
@@ -1732,7 +1717,7 @@ func TestGetDeployedVersion(t *testing.T) {
 				},
 				logger:         logger,
 				valsRuntime:    valsRuntime,
-				RenderedValues: map[string]interface{}{},
+				RenderedValues: map[string]any{},
 			}
 
 			helm := &exectest.Helm{
@@ -1851,7 +1836,7 @@ func TestHelmState_DiffReleases(t *testing.T) {
 				},
 				logger:         logger,
 				valsRuntime:    valsRuntime,
-				RenderedValues: map[string]interface{}{},
+				RenderedValues: map[string]any{},
 			}
 			_, errs := state.DiffReleases(tt.helm, []string{}, 1, false, false, false, []string{}, false, false, false, false, false)
 			if len(errs) > 0 {
@@ -1894,7 +1879,7 @@ func TestHelmState_DiffFlags(t *testing.T) {
 				},
 				logger:         logger,
 				valsRuntime:    valsRuntime,
-				RenderedValues: map[string]interface{}{},
+				RenderedValues: map[string]any{},
 			}
 			for j := range tt.releases {
 				flags, _, errs := state.flagsForDiff(tt.helm, &tt.releases[j], false, 1, nil)
@@ -1933,8 +1918,8 @@ func TestHelmState_SyncReleasesCleanup(t *testing.T) {
 				{
 					Name:  "releaseName",
 					Chart: "foo",
-					Values: []interface{}{
-						map[interface{}]interface{}{
+					Values: []any{
+						map[any]any{
 							"someList": "a,b,c",
 						},
 					},
@@ -1949,8 +1934,8 @@ func TestHelmState_SyncReleasesCleanup(t *testing.T) {
 				{
 					Name:  "releaseName",
 					Chart: "foo",
-					Values: []interface{}{
-						map[interface{}]interface{}{
+					Values: []any{
+						map[any]any{
 							"someList": "a,b,c",
 						},
 						"someFile",
@@ -1971,7 +1956,7 @@ func TestHelmState_SyncReleasesCleanup(t *testing.T) {
 				},
 				logger:         logger,
 				valsRuntime:    valsRuntime,
-				RenderedValues: map[string]interface{}{},
+				RenderedValues: map[string]any{},
 			}
 			testfs := testhelper.NewTestFs(map[string]string{
 				"/path/to/someFile": `foo: FOO`,
@@ -2020,8 +2005,8 @@ func TestHelmState_DiffReleasesCleanup(t *testing.T) {
 				{
 					Name:  "releaseName",
 					Chart: "foo",
-					Values: []interface{}{
-						map[interface{}]interface{}{
+					Values: []any{
+						map[any]any{
 							"someList": "a,b,c",
 						},
 					},
@@ -2036,8 +2021,8 @@ func TestHelmState_DiffReleasesCleanup(t *testing.T) {
 				{
 					Name:  "releaseName",
 					Chart: "foo",
-					Values: []interface{}{
-						map[interface{}]interface{}{
+					Values: []any{
+						map[any]any{
 							"someList": "a,b,c",
 						},
 						"someFile",
@@ -2058,7 +2043,7 @@ func TestHelmState_DiffReleasesCleanup(t *testing.T) {
 				},
 				logger:         logger,
 				valsRuntime:    valsRuntime,
-				RenderedValues: map[string]interface{}{},
+				RenderedValues: map[string]any{},
 			}
 			testfs := testhelper.NewTestFs(map[string]string{
 				"/path/to/someFile": `foo: bar
@@ -2316,7 +2301,7 @@ func TestHelmState_ReleaseStatuses(t *testing.T) {
 			releases: []ReleaseSpec{
 				{
 					Name: "error",
-					Values: []interface{}{
+					Values: []any{
 						"foo.yaml",
 					},
 				},
@@ -2329,7 +2314,7 @@ func TestHelmState_ReleaseStatuses(t *testing.T) {
 			releases: []ReleaseSpec{
 				{
 					Name: "error",
-					Values: []interface{}{
+					Values: []any{
 						"foo.yaml",
 					},
 					Installed: boolValue(false),
@@ -2436,6 +2421,110 @@ func TestHelmState_TestReleasesNoCleanUp(t *testing.T) {
 	}
 }
 
+func TestConditionEnabled(t *testing.T) {
+	tests := []struct {
+		name      string
+		condition string
+		values    map[string]any
+		want      bool
+		wantErr   bool
+		wantPanic bool
+	}{
+		{
+			name:      "enabled",
+			condition: "foo.enabled",
+			values: map[string]any{
+				"foo": map[string]any{
+					"enabled": true,
+				},
+			},
+			want: true,
+		},
+		{
+			name:      "disabled",
+			condition: "foo.enabled",
+			values: map[string]any{
+				"foo": map[string]any{
+					"enabled": false,
+				},
+			},
+			want: false,
+		},
+		{
+			name:      "missing enabled",
+			condition: "foo.enabled",
+			values: map[string]any{
+				"foo": map[string]any{
+					"something else": false,
+				},
+			},
+			want: false,
+		},
+		{
+			name:      "foo nil",
+			condition: "foo.enabled",
+			values: map[string]any{
+				"foo": nil,
+			},
+			wantPanic: true,
+		},
+		{
+			name:      "foo missing",
+			condition: "foo.enabled",
+			values:    map[string]any{},
+			wantPanic: true,
+		},
+		{
+			name:      "wrong suffix",
+			condition: "services.foo_enabled",
+			want:      false,
+			wantErr:   true,
+		},
+		{
+			name:      "too short condition",
+			condition: "rnd42",
+			want:      false,
+			wantErr:   true,
+		},
+		{
+			name:      "too long condition",
+			condition: "rnd42.really.enabled",
+			want:      false,
+			wantErr:   true,
+		},
+		{
+			name:      "empty",
+			condition: "",
+			want:      true,
+		},
+	}
+	for i := range tests {
+		tt := tests[i]
+		t.Run(tt.name, func(t *testing.T) {
+			if tt.wantPanic {
+				defer func() {
+					if r := recover(); r == nil {
+						t.Errorf("ConditionEnabled() for %s expected panic", tt.name)
+					}
+				}()
+			}
+			res, err := ConditionEnabled(ReleaseSpec{Condition: tt.condition}, tt.values)
+			if tt.wantErr {
+				if err == nil {
+					t.Errorf("ConditionEnabled() for %s expected err response", tt.name)
+				}
+				return
+			}
+			if err != nil {
+				t.Errorf("ConditionEnabled() for %s unexpected err %v", tt.name, err)
+			}
+			if res != tt.want {
+				t.Errorf("ConditionEnabled() for %s = %v, want %v", tt.name, res, tt.want)
+			}
+		})
+	}
+}
+
 func TestHelmState_NoReleaseMatched(t *testing.T) {
 	releases := []ReleaseSpec{
 		{
@@ -2475,7 +2564,7 @@ func TestHelmState_NoReleaseMatched(t *testing.T) {
 					Releases: releases,
 				},
 				logger:         logger,
-				RenderedValues: map[string]interface{}{},
+				RenderedValues: map[string]any{},
 			}
 			state.Selectors = []string{tt.labels}
 			errs := state.FilterReleases(false)
@@ -2636,7 +2725,7 @@ func TestHelmState_Delete(t *testing.T) {
 					Releases: releases,
 				},
 				logger:         logger,
-				RenderedValues: map[string]interface{}{},
+				RenderedValues: map[string]any{},
 			}
 			helm := &exectest.Helm{
 				Lists:   map[exectest.ListKey]string{},
@@ -3255,3 +3344,44 @@ func TestCommonDiffFlags(t *testing.T) {
 		require.Equal(t, tt.expected, result)
 	}
 }
+
+func TestAppendChartDownloadTLSFlags(t *testing.T) {
+	tests := []struct {
+		name                         string
+		defaultInsecureSkipTLSVerify bool
+		releaseInsecureSkipTLSVerify bool
+		expected                     []string
+	}{
+		{
+			name:                         "defaultInsecureSkipTLSVerify is true and releaseInsecureSkipTLSVerify is false",
+			defaultInsecureSkipTLSVerify: true,
+			releaseInsecureSkipTLSVerify: false,
+			expected:                     []string{"--insecure-skip-tls-verify"},
+		},
+		{
+			name:                         "defaultInsecureSkipTLSVerify is false and releaseInsecureSkipTLSVerify is true",
+			defaultInsecureSkipTLSVerify: false,
+			releaseInsecureSkipTLSVerify: true,
+			expected:                     []string{"--insecure-skip-tls-verify"},
+		},
+		{
+			name:                         "defaultInsecureSkipTLSVerify is false and releaseInsecureSkipTLSVerify is false",
+			defaultInsecureSkipTLSVerify: false,
+			releaseInsecureSkipTLSVerify: false,
+			expected:                     []string{},
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			st := &HelmState{}
+			release := &ReleaseSpec{}
+			st.HelmDefaults.InsecureSkipTLSVerify = tt.defaultInsecureSkipTLSVerify
+			release.InsecureSkipTLSVerify = tt.releaseInsecureSkipTLSVerify
+
+			result := st.appendChartDownloadTLSFlags([]string{}, release)
+
+			require.Equal(t, tt.expected, result)
+		})
+	}
+}
